Fixture

Struct Fixture 

pub struct Fixture {
    pub paths: Vec<String>,
    /* private fields */
}

Fields

paths: Vec<String>

Implementations

Source

impl Fixture

Create directories, files, and tear them down at will. Used throughout immutag crates for testing purposes. See tests directories of said crates for examples.

pub fn new() -> Fixture

pub fn add_dirpath(&mut self, path: String) -> Fixture

pub fn add_file(&mut self, file: String) -> Fixture

pub fn build(&mut self) -> Fixture

Builds all the directory files and paths and then writes them to disk.

pub fn teardown(&mut self, del_all: bool) -> Fixture

Teardown everything. At the moment, it’s really only suited for tearing down all the files, except the .immutag dir itself. However, more fine grained control can be added within this method. For example, teardown could take a Vec of paths to delete.