pub struct Display<'grid> { /* private fields */ }Expand description
A displayable representation of a Grid.
Implementations
Sourceimpl<'grid> Display<'grid>
impl<'grid> Display<'grid>
Sourcepub fn width(&self) -> usize
pub fn width(&self) -> usize
Returns how many columns this display takes up, based on the separator width and the number and width of the columns.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Returns whether this display takes up as many columns as were allotted to it.
It’s possible to construct tables that don’t actually use up all the columns that they could, such as when there are more columns than cells! In this case, a column would have a width of zero. This just checks for that.