Grid

Struct Grid 

pub struct Grid { /* private fields */ }
Everything needed to format the cells with the grid options.

For more information, see the module-level documentation.

Implementations

Source

impl Grid

pub fn new(options: GridOptions) -> Grid

Creates a new grid view with the given options.

pub fn reserve(&mut self, additional: usize)

Reserves space in the vector for the given number of additional cells to be added. (See vec#reserve)

pub fn add(&mut self, cell: Cell)

Adds another cell onto the vector.

pub fn fit_into_width(&self, maximum_width: usize) -> Option<Display<'_>>

Returns a displayable grid that’s been packed to fit into the given width in the fewest number of rows.

Returns None if any of the cells has a width greater than the maximum width.

pub fn fit_into_columns(&self, num_columns: usize) -> Display<'_>

Returns a displayable grid with the given number of columns, and no maximum width.